==> haskell-lifted-base-0.2.3.11-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.11
id: lifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
key: lifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
abi: d77cf1483cde455e341127bd21818416
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/lifted-base-0.2.3.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/lifted-base-0.2.3.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/lifted-base-0.2.3.11
hs-libraries: HSlifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
includes:
    inlinable.h
depends:
    base-4.9.1.0 monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.11-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.11
id: lifted-base-0.2.3.11-8iLGwbgzRdj8VUS8VipjzO
key: lifted-base-0.2.3.11-8iLGwbgzRdj8VUS8VipjzO
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
abi: 080ee3a20e0529e28d0d827e8f09b5b3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/lifted-base-0.2.3.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/lifted-base-0.2.3.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/lifted-base-0.2.3.11
hs-libraries: HSlifted-base-0.2.3.11-8iLGwbgzRdj8VUS8VipjzO
includes:
    inlinable.h
depends:
    base-4.9.1.0 monad-control-1.0.2.2-FLdbJMBsCl8Hxe7Woti7SW
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
